# Fullstack-contacts

Contact form and backend for fullstack-cms

---

## Installation

``` rb
gem 'fullstack-contacts'
```

``` sh
rails g fullstack:contacts:install
```

Edit `app/models/contact.rb` to customize `Contact` model and then run:

``` rb
rails g migration:from contact && rake db:migrate
```

You may also wish to customize front-end views editing:

- `app/views/contacts_mailer/confirmation.html.erb`
- `app/views/contacts_mailer/notify.html.erb`
- `app/views/fullstack/contacts/_form.html.erb`
- `app/views/fullstack/contacts/_success.html.erb`


## Administration

Enable contacts back-end in config/initializers/fullstack.rb:

``` rb
  # ...
  admin.group :contacts do |g|
    g.icon= "user"
    g.resource :contacts
  end
  
```

Install a widget inside your admin/dashboard to view the latest contacts:

``` erb
<%= contacts_dashboard_widget %>
```  

## Usage

``` rb
class Site::SiteController < Site::BaseController
  include Fullstack::Contacts::Actions

  page :home, "/" do
  end
  
  page :contacts, "/contacts", :parent => :home do
    @contact = Contact.new
  end
     
  action :contact, "/contact", :via => :post do    
    create_contact!(:success => polymorphic_path([:site, :contacts], :success => true))
  end
  # ...
  
end
```

``` rhtml
<!-- site/site/contacts.html.erb -->

<% if params[:success] %>
  <%= contact_success %>
<% else %>
  <%= contact_form %>
<% end %>

```

Copyright (c) 2012 mcasimir

MIT License

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
